from dataclasses import dataclass
import io
from typing import Callable, List, Any

from ngsindex import *


@dataclass
class IndexTestData:
    name: str
    data: Sequence[int]
    expect: CoordinateIndex
    err: Exception = None

    def parse(self):
        data = io.BytesIO(bytes(self.data))
        return parse_index(fileobj=data)


@dataclass
class ChunkTestData:
    begin: int
    end: int
    expect: Sequence[Chunk] = None
    ref_index: int = 0
    err: Exception = None


@dataclass
class ChunkTestDataSet:
    name: str
    data: Sequence[int]
    tests: Sequence[ChunkTestData]
    compressed: bool = False


def sparse_list(size: int, factory: Callable, *args: Tuple[int, Any]) -> List:
    sl = [factory(i) for i in range(size)]
    for idx, value in args:
        sl[idx] = value
    return sl



import argparse
import ngsindex
import json
from xphyle import STDOUT, open_


def summarize():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-o", "--output", default=STDOUT,
        help="Output file (defaults to stdout)."
    )
    parser.add_argument("index", help="Index file.")
    args = parser.parse_args()

    index = ngsindex.parse_index(args.index)
    summary = index.summarize()
    with open_(args.output, "w") as out:
        json.dump(summary, out, indent=4)



import os
from setuptools import setup
import sys
import versioneer


if sys.version_info < (3, 6):
    sys.stdout.write("ngsindex requires python3.6.\n")
    sys.exit(1)


with open(
    os.path.join(os.path.abspath(os.path.dirname(__file__)), "README.md"),
    encoding="utf-8"
) as f:
    long_description = f.read()


setup(
    name='ngsindex',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Utilities for working with NGS index formats.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/jdidion/ngsindex',
    author='John Didion',
    author_email='github@didion.net',
    license='MIT',
    packages=['ngsindex'],
    install_requires=[
        'xphyle>=4.0.0rc0'
    ],
    tests_require=[
        'pytest',
        'pytest-cov',
        'pytest-datadir',
        'dataclasses'
    ],
    entry_points={
        "console_scripts": [
            "summarize-index=ngsindex.cli:summarize"
        ]
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
        'License :: Public Domain',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
    ],
)
